@@ -5,6 +5,9 @@ import sys
 import logging
 import os
 import traceback
+from argparse import Namespace
+
+from pmb.helpers.exceptions import BuildFailedError, NonBugError
 
 from . import config
 from . import parse
@@ -15,17 +18,27 @@ from .helpers import mount
 from .helpers import other
 
 # pmbootstrap version
-__version__ = "2.2.0"
+__version__ = "2.3.1"
 
 # Python version check
 version = sys.version_info
-if version < (3, 7):
-    print("You need at least Python 3.7 to run pmbootstrap")
+if version < (3, 9):
+    print("You need at least Python 3.9 to run pmbootstrap")
     print("(You are running it with Python " + str(version.major) +
           "." + str(version.minor) + ")")
     sys.exit()
 
 
+def print_log_hint(args: Namespace) -> None:
+    # Hints about the log file (print to stdout only)
+    log_hint = "Run 'pmbootstrap log' for details."
+    if not args or not os.path.exists(args.log):
+        log_hint += (" Alternatively you can use '--details-to-stdout' to get more"
+                     " output, e.g. 'pmbootstrap --details-to-stdout init'.")
+    print()
+    print(log_hint)
+
+
 def main():
     # Wrap everything to display nice error messages
     args = None
@@ -74,6 +87,15 @@ def main():
         print("\nCaught KeyboardInterrupt, exiting …")
         sys.exit(130)  # SIGINT(2) + 128
 
+    except NonBugError as exception:
+        logging.error(f"ERROR: {exception}")
+        return 2
+
+    except BuildFailedError as exception:
+        logging.error(f"ERROR: {exception}")
+        print_log_hint(args)
+        return 3
+
     except Exception as e:
         # Dump log to stdout when args (and therefore logging) init failed
         if not args:
@@ -83,19 +105,12 @@ def main():
         logging.info("See also: <https://postmarketos.org/troubleshooting>")
         logging.debug(traceback.format_exc())
 
-        # Hints about the log file (print to stdout only)
-        log_hint = "Run 'pmbootstrap log' for details."
-        if not args or not os.path.exists(args.log):
-            log_hint += (" Alternatively you can use '--details-to-stdout' to"
-                         " get more output, e.g. 'pmbootstrap"
-                         " --details-to-stdout init'.")
-        print()
-        print(log_hint)
+        print_log_hint(args)
         print()
         print("Before you report this error, ensure that pmbootstrap is "
               "up to date.")
         print("Find the latest version here:"
-              " https://git.sr.ht/~postmarketos/pmbootstrap/refs")
+              " https://gitlab.com/postmarketOS/pmbootstrap/-/tags")
         print(f"Your version: {__version__}")
         return 1
 
