@@ -14,11 +14,13 @@ import pmb.parse.depends
 import pmb.parse.version
 
 
-def update_repository_list(args, suffix="native", check=False):
+def update_repository_list(args, suffix="native", postmarketos_mirror=True,
+                           check=False):
     """
     Update /etc/apk/repositories, if it is outdated (when the user changed the
     --mirror-alpine or --mirror-pmOS parameters).
 
+    :param postmarketos_mirror: add postmarketos mirror URLs
     :param check: This function calls it self after updating the
                   /etc/apk/repositories file, to check if it was successful.
                   Only for this purpose, the "check" parameter should be set to
@@ -41,7 +43,7 @@ def update_repository_list(args, suffix="native", check=False):
         pmb.helpers.run.root(args, ["mkdir", "-p", os.path.dirname(path)])
 
     # Up to date: Save cache, return
-    lines_new = pmb.helpers.repo.urls(args)
+    lines_new = pmb.helpers.repo.urls(args, postmarketos_mirror=postmarketos_mirror)
     if lines_old == lines_new:
         pmb.helpers.other.cache["apk_repository_list_updated"].append(suffix)
         return
@@ -57,7 +59,7 @@ def update_repository_list(args, suffix="native", check=False):
     for line in lines_new:
         pmb.helpers.run.root(args, ["sh", "-c", "echo "
                                     f"{shlex.quote(line)} >> {path}"])
-    update_repository_list(args, suffix, True)
+    update_repository_list(args, suffix, postmarketos_mirror, True)
 
 
 def check_min_version(args, suffix="native"):
@@ -143,7 +145,7 @@ def packages_get_locally_built_apks(args, packages, arch):
     :param packages: list of pkgnames
     :param arch: architecture that the locally built packages should have
     :returns: list of apk file paths that are valid inside the chroots, e.g.
-              ["/mnt/pmbootstrap-packages/x86_64/hello-world-1-r6.apk", ...]
+              ["/mnt/pmbootstrap/packages/x86_64/hello-world-1-r6.apk", ...]
     """
     channel = pmb.config.pmaports.read_config(args)["channel"]
     ret = []
@@ -157,7 +159,7 @@ def packages_get_locally_built_apks(args, packages, arch):
         if not os.path.exists(f"{args.work}/packages/{channel}/{arch}/{apk_file}"):
             continue
 
-        ret.append(f"/mnt/pmbootstrap-packages/{arch}/{apk_file}")
+        ret.append(f"/mnt/pmbootstrap/packages/{arch}/{apk_file}")
 
     return ret
 
@@ -171,7 +173,7 @@ def install_run_apk(args, to_add, to_add_local, to_del, suffix):
     :param to_add_local: return of packages_get_locally_built_apks()
     :param to_del: list of pkgnames to be deleted, this should be set to
                    conflicting dependencies in any of the packages to be
-                   installed or their dependencies (e.g. ["osk-sdl"])
+                   installed or their dependencies (e.g. ["unl0kr"])
     :param suffix: the chroot suffix, e.g. "native" or "rootfs_qemu-amd64"
     """
     # Sanitize packages: don't allow '--allow-untrusted' and other options
@@ -192,6 +194,10 @@ def install_run_apk(args, to_add, to_add_local, to_del, suffix):
         commands += [["del"] + to_del]
 
     for (i, command) in enumerate(commands):
+        # --no-interactive is a parameter to `add`, so it must be appended or apk
+        # gets confused
+        command += ["--no-interactive"]
+
         if args.offline:
             command = ["--no-network"] + command
         if i == 0:
@@ -250,13 +256,15 @@ def installed(args, suffix="native"):
 
     :returns: a dictionary with the following structure:
               { "postmarketos-mkinitfs":
-                {
-                  "pkgname": "postmarketos-mkinitfs"
-                  "version": "0.0.4-r10",
-                  "depends": ["busybox-extras", "lddtree", ...],
-                  "provides": ["mkinitfs=0.0.1"]
-                }, ...
+              {
+              "pkgname": "postmarketos-mkinitfs"
+              "version": "0.0.4-r10",
+              "depends": ["busybox-extras", "lddtree", ...],
+              "provides": ["mkinitfs=0.0.1"]
+              }, ...
+
               }
+
     """
     path = f"{args.work}/chroot_{suffix}/lib/apk/db/installed"
     return pmb.parse.apkindex.parse(path, False)
