@@ -9,10 +9,11 @@ from typing import List
 #
 # Exported functions
 #
-from pmb.config.load import load
+from pmb.config.load import load, sanity_checks
 from pmb.config.save import save
 from pmb.config.merge_with_args import merge_with_args
 from pmb.config.sudo import which_sudo
+from pmb.config.other import is_systemd_selected
 
 
 #
@@ -27,10 +28,11 @@ arch_native = pmb.parse.arch.alpine_native()
 # Update this frequently to prevent a MITM attack with an outdated version
 # (which may contain a vulnerable apk/openssl, and allows an attacker to
 # exploit the system!)
-apk_tools_min_version = {"edge": "2.14.0-r5",
-                         "v3.19": "2.14.0-r5",
-                         "v3.18": "2.14.0-r2",
-                         "v3.17": "2.12.10-r1",
+apk_tools_min_version = {"edge": "2.14.4-r0",
+                         "v3.20": "2.14.4-r0",
+                         "v3.19": "2.14.4-r0",
+                         "v3.18": "2.14.4-r0",
+                         "v3.17": "2.12.14-r0",
                          "v3.16": "2.12.9-r3",
                          "v3.15": "2.12.7-r3",
                          "v3.14": "2.12.7-r0",
@@ -89,12 +91,11 @@ config_keys = [
     "locale",
     "mirror_alpine",
     "mirrors_postmarketos",
-    "nonfree_firmware",
-    "nonfree_userland",
     "qemu_redir_stdio",
     "ssh_key_glob",
     "ssh_keys",
     "sudo_timer",
+    "systemd",
     "timezone",
     "ui",
     "ui_extras",
@@ -106,46 +107,52 @@ config_keys = [
 # $WORK gets replaced with the actual value for args.work (which may be
 # overridden on the commandline)
 defaults = {
+    # This first chunk matches config_keys
     "aports": "$WORK/cache_git/pmaports",
+    "boot_size": "256",
+    "build_default_device_arch": False,
+    "build_pkgs_on_install": True,
     "ccache_size": "5G",
-    "is_default_channel": True,
-    "cipher": "aes-xts-plain64",
-    "config": (os.environ.get('XDG_CONFIG_HOME') or
-               os.path.expanduser("~/.config")) + "/pmbootstrap.cfg",
     "device": "qemu-amd64",
     "extra_packages": "none",
-    "fork_alpine": False,
+    "extra_space": "0",
     "hostname": "",
-    "build_pkgs_on_install": True,
-    # A higher value is typically desired, but this can lead to VERY long open
-    # times on slower devices due to host systems being MUCH faster than the
-    # target device (see issue #429).
-    "iter_time": "200",
+    "is_default_channel": True,
     "jobs": str(multiprocessing.cpu_count() + 1),
     "kernel": "stable",
     "keymap": "",
     "locale": "en_US.UTF-8",
-    "log": "$WORK/log.txt",
+    # NOTE: mirrors use http by default to leverage caching
     "mirror_alpine": "http://dl-cdn.alpinelinux.org/alpine/",
     # NOTE: mirrors_postmarketos variable type is supposed to be
     #       comma-separated string, not a python list or any other type!
     "mirrors_postmarketos": "http://mirror.postmarketos.org/postmarketos/",
-    "nonfree_firmware": True,
-    "nonfree_userland": False,
-    "ssh_keys": False,
+    "qemu_redir_stdio": False,
     "ssh_key_glob": "~/.ssh/id_*.pub",
+    "ssh_keys": False,
+    "sudo_timer": False,
+    "systemd": "default",
     "timezone": "GMT",
     "ui": "console",
     "ui_extras": False,
     "user": "user",
     "work": os.path.expanduser("~") + "/.local/var/pmbootstrap",
-    "boot_size": "256",
-    "extra_space": "0",
-    "sudo_timer": False,
-    "qemu_redir_stdio": False,
-    "build_default_device_arch": False,
+
+    # These values are not part of config_keys
+    "cipher": "aes-xts-plain64",
+    "config": (os.environ.get('XDG_CONFIG_HOME') or
+               os.path.expanduser("~/.config")) + "/pmbootstrap.cfg",
+    "fork_alpine": False,
+    # A higher value is typically desired, but this can lead to VERY long open
+    # times on slower devices due to host systems being MUCH faster than the
+    # target device (see issue #429).
+    "iter_time": "200",
+    "log": "$WORK/log.txt",
 }
 
+allowed_values = {
+    "systemd": ["default", "always", "never"],
+}
 
 # Whether we're connected to a TTY (which allows things like e.g. printing
 # progress bars)
@@ -497,7 +504,6 @@ kconfig_options_containers = {
             "CGROUP_PERF": True,  # Optional section
             "NET_CLS_CGROUP": True,  # Optional section
             "FAIR_GROUP_SCHED": True,  # Optional section
-            "RT_GROUP_SCHED": True,  # Optional section
             "IP_NF_TARGET_REDIRECT": True,  # Optional section
             "IP_VS": True,  # Optional section
             "IP_VS_NFCT": True,  # Optional section
@@ -554,7 +560,7 @@ kconfig_options_containers = {
         }
     },
     ">=3.13": {
-        "all": { # needed for iptables-nft (used by docker,tailscale)
+        "all": {  # needed for iptables-nft (used by docker,tailscale)
             "NFT_COMPAT": True,
         }
     },
@@ -669,6 +675,8 @@ kconfig_options_community = {
             "UCLAMP_TASK": True,  # Scheduler hints
             "UCLAMP_TASK_GROUP": True,  # Scheduler hints
             "UHID": True,  # e.g. Bluetooth input devices
+            "USB_STORAGE": True,  # USB mass storage devices
+            "RT_GROUP_SCHED": False, # https://gitlab.com/postmarketOS/pmaports/-/issues/2652
         },
     },
 }
@@ -682,13 +690,16 @@ kconfig_options_uefi = {
             "DMI": True,
             "EFI_ESRT": True,
             "EFI_VARS_PSTORE": True,
-            "EFI_PARAMS_FROM_FDT": True,
             "EFI_RUNTIME_WRAPPERS": True,
-            "EFI_GENERIC_STUB": True,
+            "VFAT_FS": True,
         },
         "x86_64": {
             "EFI_MIXED": True,
         },
+        "aarch64 armv7": {
+            "EFI_GENERIC_STUB": True,
+            "EFI_PARAMS_FROM_FDT": True,
+        },
     },
     ">=6.1.0": {
         "aarch64": {
@@ -741,6 +752,7 @@ apkbuild_attributes = {
     "pkgname": {},
     "pkgrel": {},
     "pkgver": {},
+    "sha512sums": {},
     "subpackages": {},
     "url": {},
 
@@ -789,6 +801,8 @@ apkbuild_custom_valid_options = [
     "pmb:cross-native",
     "pmb:gpu-accel",
     "pmb:strict",
+    "pmb:systemd",
+    "pmb:systemd-never",
 ]
 
 # Variables from deviceinfo. Reference: <https://postmarketos.org/deviceinfo>
@@ -818,17 +832,17 @@ deviceinfo_attributes = [
     "flash_heimdall_partition_kernel",
     "flash_heimdall_partition_initfs",
     "flash_heimdall_partition_rootfs",
-    "flash_heimdall_partition_system", # deprecated
+    "flash_heimdall_partition_system",  # deprecated
     "flash_heimdall_partition_vbmeta",
     "flash_heimdall_partition_dtbo",
     "flash_fastboot_partition_kernel",
     "flash_fastboot_partition_rootfs",
-    "flash_fastboot_partition_system", # deprecated
+    "flash_fastboot_partition_system",  # deprecated
     "flash_fastboot_partition_vbmeta",
     "flash_fastboot_partition_dtbo",
     "flash_rk_partition_kernel",
     "flash_rk_partition_rootfs",
-    "flash_rk_partition_system", # deprecated
+    "flash_rk_partition_system",  # deprecated
     "flash_mtkclient_partition_kernel",
     "flash_mtkclient_partition_rootfs",
     "flash_mtkclient_partition_vbmeta",
@@ -838,7 +852,7 @@ deviceinfo_attributes = [
     "generate_bootimg",
     "header_version",
     "bootimg_qcdt",
-    "bootimg_mtk_mkimage", # deprecated
+    "bootimg_mtk_mkimage",  # deprecated
     "bootimg_mtk_label_kernel",
     "bootimg_mtk_label_ramdisk",
     "bootimg_dtb_second",
@@ -1097,10 +1111,6 @@ git_repos = {
     "pmaports": "https://gitlab.com/postmarketOS/pmaports.git",
 }
 
-# When a git repository is considered outdated (in seconds)
-# (Measuring timestamp of FETCH_HEAD: https://stackoverflow.com/a/9229377)
-git_repo_outdated = 3600 * 24 * 2
-
 #
 # APORTGEN
 #
@@ -1165,5 +1175,5 @@ sideload_sudo_prompt = "[sudo] password for %u@%h: "
 #
 # CI
 #
-# Valid options für 'pmbootstrap ci', see https://postmarketos.org/pmb-ci
+# Valid options for 'pmbootstrap ci', see https://postmarketos.org/pmb-ci
 ci_valid_options = ["native", "slow"]
