@@ -3,34 +3,39 @@
 import argparse
 import copy
 import os
+import sys
 
 try:
     import argcomplete
 except ImportError:
-    argcomplete = False
+    pass
 
 import pmb.config
 import pmb.parse.arch
 import pmb.helpers.args
 import pmb.helpers.pmaports
 
-""" This file is about parsing command line arguments passed to pmbootstrap, as
-    well as generating the help pages (pmbootstrap -h). All this is done with
-    Python's argparse. The parsed arguments get extended and finally stored in
-    the "args" variable, which is prominently passed to most functions all
-    over the pmbootstrap code base.
+"""This file is about parsing command line arguments passed to pmbootstrap, as
+   well as generating the help pages (pmbootstrap -h). All this is done with
+   Python's argparse. The parsed arguments get extended and finally stored in
+   the "args" variable, which is prominently passed to most functions all
+   over the pmbootstrap code base.
 
-    See pmb/helpers/args.py for more information about the args variable. """
+   See pmb/helpers/args.py for more information about the args variable.
+"""
 
 
 def toggle_other_boolean_flags(*other_destinations, value=True):
-    """ Helper function to group several argparse flags to one. Sets multiple
-        other_destination to value.
+    """Group several argparse flags to one.
 
-        :param other_destinations: 'the other argument names' str
-        :param value 'the value to set the other_destinations to' bool
-        :returns custom Action"""
+    Sets multiple other_destination to value.
 
+    :param other_destinations: 'the other argument names' str
+
+    :param value 'the value to set the other_destinations to' bool
+
+    :returns custom Action
+    """
     class SetOtherDestinationsAction(argparse.Action):
         def __init__(self, option_strings, dest, **kwargs):
             super().__init__(option_strings, dest, nargs=0, const=value,
@@ -44,10 +49,12 @@ def toggle_other_boolean_flags(*other_destinations, value=True):
 
 
 def type_ondev_cp(val):
-    """ Parse and validate arguments to 'pmbootstrap install --ondev --cp'.
+    """Parse and validate arguments to 'pmbootstrap install --ondev --cp'.
 
-        :param val: 'HOST_SRC:CHROOT_DEST' string
-        :returns: (HOST_SRC, CHROOT_DEST) """
+    :param val: 'HOST_SRC:CHROOT_DEST' string
+
+    :returns: (HOST_SRC, CHROOT_DEST)
+    """
     ret = val.split(":")
 
     if len(ret) != 2:
@@ -81,6 +88,8 @@ def arguments_install(subparser):
                      " important password!")
     ret.add_argument("--no-cgpt", help="do not use cgpt partition table",
                      dest="install_cgpt", action="store_false", default=True)
+    ret.add_argument("--zap", help="zap chroots before installing",
+                     action="store_true")
 
     # Image type
     group_desc = ret.add_argument_group(
@@ -96,9 +105,11 @@ def arguments_install(subparser):
                        default=None)
     group.add_argument("--split", help="create separate boot and root image"
                        " files", action="store_true")
-    group.add_argument("--sdcard", help="do not create an image file, instead"
-                       " write to the given SD card device (e.g."
-                       " '/dev/mmcblk0')", metavar="BLOCKDEV")
+    group.add_argument("--disk", "--sdcard",
+                       help="do not create an image file, instead"
+                            " write to the given block device (SD card, USB"
+                            " stick, etc.), for example: '/dev/mmcblk0'",
+                       metavar="BLOCKDEV")
     group.add_argument("--android-recovery-zip",
                        help="generate TWRP flashable zip (recommended read:"
                             " https://postmarketos.org/recoveryzip)",
@@ -106,9 +117,9 @@ def arguments_install(subparser):
     group.add_argument("--no-image", help="do not generate an image",
                        action="store_true", dest="no_image")
 
-    # Image type "--sdcard" related
-    group = ret.add_argument_group("optional image type 'sdcard' arguments")
-    group.add_argument("--rsync", help="update the SD card using rsync",
+    # Image type "--disk" related
+    group = ret.add_argument_group("optional image type 'disk' arguments")
+    group.add_argument("--rsync", help="update the disk using rsync",
                        action="store_true")
 
     # Image type "--android-recovery-zip" related
@@ -215,8 +226,8 @@ def arguments_sideload(subparser):
                      default="22")
     ret.add_argument("--user", help="use a different username than the"
                      " one set in init")
-    ret.add_argument("--arch", help="use a different architecture than the one"
-                                    " set in init")
+    ret.add_argument("--arch", help="skip automatic architecture deduction and use the"
+                                    " given value")
     ret.add_argument("--install-key", help="install the apk key from this"
                      " machine if needed",
                      action="store_true", dest="install_key")
@@ -285,6 +296,19 @@ def arguments_flasher(subparser):
                    " inside the device rootfs chroot on this computer")
     sub.add_parser("list_devices", help="show connected devices")
 
+    group = ret.add_argument_group("heimdall options", \
+                                   "With heimdall as"
+                                   " flash method, the device automatically"
+                                   " reboots after each flash command. Use"
+                                   " --no-reboot and --resume for multiple"
+                                   " flash actions without reboot.")
+    group.add_argument("--no-reboot", dest="no_reboot",
+                       help="don't automatically reboot after flashing",
+                       action="store_true")
+    group.add_argument("--resume", dest="resume",
+                       help="resume flashing after using --no-reboot",
+                       action="store_true")
+
     return ret
 
 
@@ -466,8 +490,8 @@ def arguments_kconfig(subparser):
                        " kernels, even the ones that would be ignored by"
                        " default")
     check.add_argument("--arch", choices=arch_choices, dest="arch")
-    check.add_argument("--file", action="store_true", help="check a file"
-                       " directly instead of a config in a package")
+    check.add_argument("--file", help="check a file directly instead of a"
+                       " config in a package")
     check.add_argument("--no-details", action="store_false",
                        dest="kconfig_check_details",
                        help="print one generic error per component instead of"
@@ -476,7 +500,7 @@ def arguments_kconfig(subparser):
         check.add_argument(f"--{name}", action="store_true",
                            dest=f"kconfig_check_{name}",
                            help=f"check options needed for {name} too")
-    add_kernel_arg(check)
+    add_kernel_arg(check, nargs="*")
 
     # "pmbootstrap kconfig edit"
     edit = sub.add_parser("edit", help="edit kernel aport config")
@@ -499,11 +523,22 @@ def arguments_kconfig(subparser):
     add_kernel_arg(migrate)
 
 
+def arguments_repo_bootstrap(subparser):
+    arch_native = pmb.config.arch_native
+    arch_choices = set(pmb.config.build_device_architectures + [arch_native])
+
+    ret = subparser.add_parser("repo_bootstrap")
+    ret.add_argument("repository",
+                     help="which repository to bootstrap (e.g. systemd)")
+    ret.add_argument("--arch", choices=arch_choices, dest="arch")
+    return ret
+
+
 def arguments_repo_missing(subparser):
     ret = subparser.add_parser("repo_missing")
     package = ret.add_argument("package", nargs="?", help="only look at a"
                                " specific package and its dependencies")
-    if argcomplete:
+    if "argcomplete" in sys.modules:
         package.completer = package_completer
     ret.add_argument("--arch", choices=pmb.config.build_device_architectures,
                      default=pmb.config.arch_native)
@@ -522,9 +557,7 @@ def arguments_lint(subparser):
 
 def arguments_status(subparser):
     ret = subparser.add_parser("status",
-                               help="quick health check for the work dir")
-    ret.add_argument("--details", action="store_true",
-                     help="list passing checks in detail, not as summary")
+                               help="show a config and pmaports overview")
     return ret
 
 
@@ -586,18 +619,18 @@ def kernel_completer(prefix, action, parser=None, parsed_args=None):
 
 def add_packages_arg(subparser, name="packages", *args, **kwargs):
     arg = subparser.add_argument(name, *args, **kwargs)
-    if argcomplete:
+    if "argcomplete" in sys.modules:
         arg.completer = package_completer
 
 
 def add_kernel_arg(subparser, name="package", nargs="?", *args, **kwargs):
     arg = subparser.add_argument("package", nargs=nargs, help="kernel package"
                                  " (e.g. linux-postmarketos-allwinner)")
-    if argcomplete:
+    if "argcomplete" in sys.modules:
         arg.completer = kernel_completer
 
 
-def arguments():
+def get_parser():
     parser = argparse.ArgumentParser(prog="pmbootstrap")
     arch_native = pmb.config.arch_native
     arch_choices = set(pmb.config.build_device_architectures + [arch_native])
@@ -679,6 +712,7 @@ def arguments():
     sub.add_parser("work_migrate", help="run this before using pmbootstrap"
                                         " non-interactively to migrate the"
                                         " work folder version on demand")
+    arguments_repo_bootstrap(sub)
     arguments_repo_missing(sub)
     arguments_kconfig(sub)
     arguments_export(sub)
@@ -802,9 +836,15 @@ def arguments():
     aportgen = sub.add_parser("aportgen", help="generate a postmarketOS"
                               " specific package build recipe"
                               " (aport/APKBUILD)")
-    aportgen.add_argument("--fork-alpine", help="fork the alpine upstream"
-                          " package", action="store_true",
-                          dest="fork_alpine")
+    aportgen_fork_alpine = aportgen.add_mutually_exclusive_group()
+    aportgen_fork_alpine.add_argument("-a", "--fork-alpine",
+                                      help="fork the alpine upstream package",
+                                      action="store_true", dest="fork_alpine")
+    aportgen_fork_alpine.add_argument("-r", "--fork-alpine-retain-branch",
+                                      help="fork the alpine upstream, but don't change "
+                                      "branch to match the current channel",
+                                      action="store_true",
+                                      dest="fork_alpine_retain_branch")
     add_packages_arg(aportgen, nargs="+")
 
     # Action: build
@@ -893,13 +933,24 @@ def arguments():
     sub.add_parser("pull", help="update all git repositories that pmbootstrap"
                    " cloned (pmaports, etc.)")
 
-    if argcomplete:
+    if "argcomplete" in sys.modules:
         argcomplete.autocomplete(parser, always_complete_options="long")
 
+    return parser
+
+def arguments():
+
     # Parse and extend arguments (also backup unmodified result from argparse)
-    args = parser.parse_args()
+    args = get_parser().parse_args()
+
     setattr(args, "from_argparse", copy.deepcopy(args))
     setattr(args.from_argparse, "from_argparse", args.from_argparse)
+
+    if getattr(args, "fork_alpine_retain_branch", False):
+        # fork_alpine_retain_branch largely matches the behaviour of fork_alpine, so
+        # just set fork_alpine here to reduce repetition.
+        args.fork_alpine = args.fork_alpine_retain_branch
+
     pmb.helpers.args.init(args)
 
     if getattr(args, "go_mod_cache", None) is None:
